@@ -1,15 +1,3 @@
-terminated_error = function(inst) {
-  msg = sprintf(
-    fmt = "TuningInstance (tsk:%s, lrn:%s, term:%s) terminated",
-    inst$objective$task$id,
-    inst$objective$learner$id,
-    format(inst$terminator)
-  )
-
-  set_class(list(message = msg, call = NULL), c(
-    "terminated_error", "error", "condition"))
-}
-
 measures_to_codomain = function(measures) {
   Codomain$new(map(as_measures(measures), function(s) {
     ParamDbl$new(id = s$id, tags = ifelse(s$minimize, "minimize", "maximize"))
