@@ -53,10 +53,24 @@ tnrs = function(.keys, ...) {
 #' @template param_callbacks
 #'
 #' @inheritSection TuningInstanceSingleCrit Resources
+#' @inheritSection TuningInstanceSingleCrit Default Measures
 #'
 #' @export
 #' @inherit TuningInstanceSingleCrit examples
 ti = function(task, learner, resampling, measures = NULL, terminator, search_space = NULL, store_benchmark_result = TRUE, store_models = FALSE, check_values = FALSE, allow_hotstart = FALSE, keep_hotstart_stack = FALSE, evaluate_default = FALSE, callbacks = list()) {
   TuningInstance = if (!is.list(measures)) TuningInstanceSingleCrit else TuningInstanceMultiCrit
-  TuningInstance$new(task, learner, resampling, measures, terminator, search_space, store_benchmark_result, store_models, check_values, allow_hotstart, keep_hotstart_stack, evaluate_default, callbacks)
+  TuningInstance$new(
+    task = task,
+    learner = learner,
+    resampling = resampling,
+    measures,
+    terminator = terminator,
+    search_space = search_space,
+    store_benchmark_result = store_benchmark_result,
+    store_models = store_models,
+    check_values = check_values,
+    allow_hotstart = allow_hotstart,
+    keep_hotstart_stack = keep_hotstart_stack,
+    evaluate_default = evaluate_default,
+    callbacks = callbacks)
 }
