@@ -8,9 +8,6 @@
 "_PACKAGE"
 
 .onLoad = function(libname, pkgname) {
-  # CRAN OMP THREAD LIMIT
-  Sys.setenv("OMP_THREAD_LIMIT" = 2)
-
   # nocov start
   x = utils::getFromNamespace("mlr_reflections", ns = "mlr3")
   x$tuner_properties = "dependencies"
